@@ -138,7 +138,11 @@ def stop():
 def run():
     messagebox.showinfo("Running", "Program is running")
     #python3 was used to deal with Debian still linking python with python2 instead of python3
-    child = subprocess.Popen('python3 grab.py', shell=True, stdout=subprocess.PIPE, text=True)
+    try:
+        child = subprocess.Popen('grab-reddit', shell=True, stdout=subprocess.PIPE, text=True)
+    except:
+        child = subprocess.Popen('python3 grab.py', shell=True, stdout=subprocess.PIPE, text=True)
+
     data = child.communicate()[0]
     rc = child.returncode
     print(data)
@@ -350,7 +354,10 @@ def changetheme():
     print("placeholder")
     writeconf()
     root.destroy()
-    subprocess.Popen('python3 gui.py', shell=True, text=True)
+    try:
+        subprocess.Popen('grab-reddit-gui', shell=True, text=True)
+    except:
+        subprocess.Popen('python3 gui.py', shell=True, text=True)
 
 #shrinks the window back to original size
 def winshr():
@@ -377,9 +384,11 @@ def main():
     #Initialise#
     ############
 
+    global pathdef
     #choose default path
     pathdef = str(os.path.join(Path.home(), "Downloads", "grab-bot"))
 
+    global config
     #config initialisation
     config = configparser.ConfigParser()
 
@@ -405,13 +414,17 @@ def main():
     #read config
     readconf()
 
+    global root
     #main window
     root = tk.Tk()
     root.title("grab - Reddit download bot")
 
+    global theme
     #define theme
     theme = ttk.Style()
 
+    global background
+    global foreground
     print("Using " + seltheme + " theme")
     if seltheme == "light":
         root.configure(bg="#ffffff")
@@ -495,23 +508,30 @@ def main():
     else:
         print("Sorry, this theme could not be found")
 
+    global main
     #main frame
     main = ttk.Frame(root)
     main.grid(row=0, column=0, sticky="W", padx=5, pady=5)
 
+    global normal
     #frame for listbox and main buttons
     normal = ttk.Frame(main)
     normal.grid(row=0, column=0, sticky="W")
 
+    global var
     #subs label
     ttk.Label(normal, text="Active subreddits:", font="none 16").grid(row=0, column=0)
     var = tk.StringVar()
 
+    global cnnsublist
+    global lsublist
+    global labelsublist
     #change the list of subs to fit
     cnnsublist = sublist.replace(';', '\n')
     lsublist = sublist.split(";")
     labelsublist = [x for x in lsublist if x]
 
+    global lbox
     #multiple doesn't work with my method
     #lbox = tk.Listbox(window, listvariable=var, selectmode="multiple", width=24)
     #create a listbox with the proper theme
@@ -539,6 +559,7 @@ def main():
     #run the program
     ttk.Button(main, text="Run", command=run).grid(row=1, column=0, sticky="E")
 
+    global butexp
     #expand
     butexp = ttk.Button(main, text=">", command=winexp)
     butexp.grid(row=1, column=1, sticky="W")
